@@ -9,10 +9,11 @@
     @Copyright (c) 2016-2017
 */
 
-const work_dir=process.cwd();
-
-module.exports=function(app){
-    app.set('views',work_dir+'/app/views');
-    app.set('view engine','jade');
+const work_dir = process.cwd();
 
+module.exports = function (callback, app, db, nylon_path) {
+    app.set('views', work_dir + '/app/views');
+    app.set('views', nylon_path + '/lib/public/views');
+    app.set('view engine', 'jade');
+    callback();
 }
\ No newline at end of file
