@@ -19,7 +19,7 @@ const work_dir = process.cwd();
 var loadSchema = function (models, callback) {
 
     async.each(models, function (model, next) {
-        logger.info("Load Data Model :: " + model.replace(work_dir,""));
+        logger.info("Load Data Model :: " + model.replace(work_dir, ""));
         try {
             fs.readFile(model, 'utf8', function (err, data) {
                 if (err) next(err);
@@ -29,6 +29,7 @@ var loadSchema = function (models, callback) {
             });
         }
         catch (err) {
+            logger.error(err);
             next(err);
         }
 
@@ -36,15 +37,20 @@ var loadSchema = function (models, callback) {
         callback(err);
     });
 }
-module.exports = function (app) {
+module.exports = function (callback, app) {
     fscan.scan(work_dir + "/app/models", ".model.json", true, function (err, models) {
         loadSchema(models, function (err) {
             logger.info("Load Data Mode is ok");
+
+
+            app.use(function (req, res, next) {
+                req.ajv = ajv;
+                next();
+            });
+
+            callback();
         });
     });
 
-    app.use(function (req, res, next) {
-        req.ajv = ajv;
-        next();
-    });
+
 }
\ No newline at end of file
