@@ -51,7 +51,7 @@ var loadRouter = function (app, routes, callback) {
 }
 
 module.exports = function (callback, app, db, nylon_path) {
-    app = require('./../routes/oauth.routes')(app);
+    app = require('./../routes/oauth.routes')(app,nylon_path);
     fscan.scan(work_dir + route_dir, ".routes.js", true, function (err, routes) {
         loadRouter(app, routes, function (err, app) {
 
